from playerdo.backends.cmus import *
from playerdo.backends.moc import *
from playerdo.backends.rhythmbox import *
from playerdo.backends.shellfm import *
from playerdo.backends.mpris import *
from playerdo.backends.mpris2 import *
from playerdo.backends.banshee import *
from playerdo.backends.quodlibet import *

